mysql.exceptions.internal.Affected_Rows_Unavailable

Package mysql :: Package exceptions :: Module internal :: Class Affected_Rows_Unavailable |
[hide private]
[frames] | no frames]

# Class Affected_Rows_Unavailable

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                              Affected_Rows_Unavailable

The number of affected rows is not available.

This can be because the query returned an error, or `store_result` was not set on a SELECT query.

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__getitem__`, `__init__`, `__str__`